<!---
Please read this!

Before opening a new issue, make sure to skim through the documentation
at http://km3py.pages.km3net.de/km3pipe
--->

### Summary

(Summarise the feature and try to provide a usage example.)

### Describe a possible workaround to achieve the same functionality

(Is there already a way to get the job done?)

/label ~enhancement
